#
# spec file for package ghc-microstache
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name microstache
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.0.2.3
Release:        4.22
Summary:        Mustache templates for Haskell
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/3.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-aeson-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-deepseq-prof
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-directory-prof
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-filepath-prof
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-parsec-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-unordered-containers-prof
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-vector-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-base-orphans-devel
BuildRequires:  ghc-base-orphans-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-hunit-prof
BuildRequires:  ghc-tasty-prof
%endif

%description
Mustache templates for Haskell.

Based on 'stache' library, which uses 'megaparsec'. This library uses 'parsec',
thus the name: 'microstache'.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Fri Oct 13 2023 Peter Simons <psimons@suse.com>
- Update microstache to version 1.0.2.3 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Jun 27 2023 Peter Simons <psimons@suse.com>
- Update microstache to version 1.0.2.3 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Wed Mar 15 2023 Peter Simons <psimons@suse.com>
- Update microstache to version 1.0.2.3 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Jan  9 2023 Peter Simons <psimons@suse.com>
- Update microstache to version 1.0.2.3.
  [#]# microstache 1.0.2.3
  - Support `parsec-3.1.16.*`
* Thu Aug 11 2022 Peter Simons <psimons@suse.com>
- Update microstache to version 1.0.2.2.
  Upstream has not updated the file "CHANGELOG.md" since the last
  release.
* Mon Jun 20 2022 Peter Simons <psimons@suse.com>
- Update microstache to version 1.0.2.1 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon May 16 2022 Peter Simons <psimons@suse.com>
- Update microstache to version 1.0.2.1.
  [#]# microstache 1.0.2.1
  - Support `transformers-0.6`
* Sat Jan  1 2022 Peter Simons <psimons@suse.com>
- Update microstache to version 1.0.2 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat Nov 20 2021 psimons@suse.com
- Update microstache to version 1.0.2 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Nov 15 2021 psimons@suse.com
- Update microstache to version 1.0.2 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun Oct 10 2021 psimons@suse.com
- Update microstache to version 1.0.2.
  [#]# microstache 1.0.2
  - Support `aeson-2.0.0.0`
* Mon Apr 26 2021 psimons@suse.com
- Add microstache at version 1.0.1.2 revision 1.
